@@ -20,10 +20,10 @@ class ObjectConstructorActionsProvider
 {
   std::vector<ObjectConstructor*> mctors[NormalModePopupObjects::NumberOfMenus];
 public:
-  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree ) Q_DECL_OVERRIDE;
+  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree ) override;
   bool executeAction( int menu, int& id, const std::vector<ObjectHolder*>& os,
                       NormalModePopupObjects& popup,
-                      KigPart& doc, KigWidget& w, NormalMode& m ) Q_DECL_OVERRIDE;
+                      KigPart& doc, KigWidget& w, NormalMode& m ) override;
 };
 
 #endif // OBJECTCONSTRUCTORACTIONSPROVIDER_H
